@@ -457,6 +457,7 @@ class Auth(object):
             bigquery_imports_bucket=settings.get("bigquery_bucket"),
             config_bucket=settings.get("config_bucket"),
             firestore_imports_bucket=settings.get("firestore_bucket"),
+            redis_imports_bucket=settings.get("redis_bucket"),
             verbose=self.verbose,
         )
 
@@ -468,6 +469,7 @@ class Auth(object):
         params = self.secrets.resolve({
             'app_project': self.settings['github']['app_project'],
             'org': self.settings['github']['org'],
+            'org_id': self.settings['github']['org_id'],
             'owner_team': self.settings['github']['owner_team'],
             'role_team': self.settings['github']['role_team'],
             'token': token,
@@ -603,19 +605,6 @@ class Auth(object):
         })
         return Keyserver(**params)
 
-    def labinspection(self):
-        """Connect to Lab Inspection DB."""
-        from bitsapiclient.services.labinspection import LabInspection
-        params = self.secrets.resolve({
-            'server': self.settings['mysql_servers']['labinspection']['db_host'],
-            'port': self.settings['mysql_servers']['labinspection']['db_port'],
-            'user': self.settings['mysql_servers']['labinspection']['db_user'],
-            'password': self.settings['mysql_servers']['labinspection']['db_pass'],
-            'db': self.settings['mysql_servers']['labinspection']['db'],
-            'verbose': self.verbose,
-        })
-        return LabInspection(**params)
-
     def ldapupdate(self):
         """Connect to the LDAPUpdate class."""
         from bits.ldap.update import LDAPUpdate
